@@ -23,13 +23,17 @@
 #include <kpagewidgetmodel.h>
 
 class WalletControlWidget;
-class KWalletManagerWidgetItem : public KPageWidgetItem {
+class KWalletManagerWidgetItem : public KPageWidgetItem
+{
     Q_OBJECT
 public:
-    KWalletManagerWidgetItem(QWidget* widgetParent, const QString& walletName);
+    KWalletManagerWidgetItem(QWidget *widgetParent, const QString &walletName);
 
     void updateWalletDisplay();
-    const QString& walletName() const { return _walletName; }
+    const QString &walletName() const
+    {
+        return _walletName;
+    }
     bool openWallet();
 
 private:
